#!/bin/bash -le
# purpose: Create package and place it in /dock
# requires: /gridded_glm to be mounted with package contents (gridded_glm in repository)
# note: The shebang at the top of this file is needed as-is. The '-l' will
#       load the .bashrc which allows us to use conda. The '-e' triggers exit
#       on error behavior. We cannot use '/usr/bin/env bash -le' since most
#       linux versions only parse the first two arguments of a shebang.

if [ $# -eq 1 ]; then
    version=$1
    lmatools_ref=minvaluegrids
    glmtools_ref=ugf-newgrid
elif [ $# -eq 3 ]; then
    version=$1
    lmatools_ref=minvaluegrids
    glmtools_ref=ugf-newgrid
else
    echo "Usage: package.sh vX.Y.Z [lmatools_ref glmtools_ref]"
    exit 1
fi

pkg_name=cspp_geo_gridded_glm-${version}
DIST=${DIST:-"/dock"}

make_dockerfile() {
    cat >$DIST/Dockerfile <<EOF
# docker build . -f Dockerfile -t gitlab.ssec.wisc.edu:5555/cspp_geo/cspp-geo-gridded-glm/run_package:${version}
# docker run -it -v /path/to/data:/work --rm gitlab.ssec.wisc.edu:5555/cspp_geo/cspp-geo-gridded-glm/run_package:${version} make_glm_grids.sh OR_GLM-L2-LCFA_*.nc
FROM centos:7
RUN mkdir -p /opt/ssec && mkdir -p /work
ADD ${pkg_name}.tar.xz /opt/ssec
WORKDIR /work
ENV CSPP_GEO_GGLM_HOME=/opt/ssec/${pkg_name}
ENV PATH=\$PATH:/opt/ssec/${pkg_name}/bin
EOF

}


conda activate build

# Debug Info
which python
conda info -a
conda list --export
echo "Version specified: ${version}"
echo "lmatools reference: ${lmatools_ref}"
echo "glmtools reference: ${glmtools_ref}"

# Turn on command printing here because we don't need all of the `conda`
# internal bash commands to pollute our output
set -x

# Install glmtools and related packages
# All dependencies should have been built with the buildbucket
# Careful: Could result in missing dependencies but we want reproducibility
pip install --no-deps git+https://github.com/deeplycloudy/lmatools.git@${lmatools_ref}
pip install --no-deps git+https://github.com/deeplycloudy/stormdrain.git
pip install --no-deps git+https://github.com/deeplycloudy/glmtools.git@${glmtools_ref}

# Build a tarball version of the current conda environment
# TODO: Add conda cleanup commands similar to what Polar2Grid uses to save space
conda_tb=conda_lmatools-${lmatools_ref}_glmtools-${glmtools_ref}.tar.gz
conda pack --n-threads $(nproc) -n build -o ${conda_tb}

# Build up our package directory
mkdir -p ${pkg_name}
cd ${pkg_name}
mkdir -p bin opt/conda
# Copy package scripts/data to package directory
cp /gridded_glm/PACKAGE_README.md ./README.md
cp /gridded_glm/bin/* ./bin/
# Untar the tarball so we can put things where we want
tar -xz -C ./opt/conda -f ../${conda_tb}
# Go back to original work directory
cd ..

# Create tarball of package directory
XZ_DEFAULTS="--threads=$(nproc)" tar -Jcf --uid 0 --gid 0 ${pkg_name}.tar.xz ${pkg_name}
mv ${pkg_name}.tar.xz ${DIST}/
make_dockerfile
